summaryrefslogtreecommitdiff
path: root/var/spack/repos/builtin/packages/llvm-openmp-ompt/package.py
diff options
context:
space:
mode:
Diffstat (limited to 'var/spack/repos/builtin/packages/llvm-openmp-ompt/package.py')
-rw-r--r--var/spack/repos/builtin/packages/llvm-openmp-ompt/package.py46
1 files changed, 11 insertions, 35 deletions
diff --git a/var/spack/repos/builtin/packages/llvm-openmp-ompt/package.py b/var/spack/repos/builtin/packages/llvm-openmp-ompt/package.py
index 2526cd4d03..bc274649f6 100644
--- a/var/spack/repos/builtin/packages/llvm-openmp-ompt/package.py
+++ b/var/spack/repos/builtin/packages/llvm-openmp-ompt/package.py
@@ -1,27 +1,8 @@
-##############################################################################
-# Copyright (c) 2013-2017, Lawrence Livermore National Security, LLC.
-# Produced at the Lawrence Livermore National Laboratory.
+# Copyright 2013-2018 Lawrence Livermore National Security, LLC and other
+# Spack Project Developers. See the top-level COPYRIGHT file for details.
#
-# This file is part of Spack.
-# Created by Todd Gamblin, tgamblin@llnl.gov, All rights reserved.
-# LLNL-CODE-647188
-#
-# For details, see https://github.com/spack/spack
-# Please also see the NOTICE and LICENSE files for our notice and the LGPL.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License (as
-# published by the Free Software Foundation) version 2.1, February 1999.
-#
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the IMPLIED WARRANTY OF
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the terms and
-# conditions of the GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-##############################################################################
+# SPDX-License-Identifier: (Apache-2.0 OR MIT)
+
from spack import *
@@ -32,19 +13,14 @@ class LlvmOpenmpOmpt(CMakePackage):
changes for OMPT, the OpenMP Tools interface"""
homepage = "https://github.com/OpenMPToolsInterface/LLVM-openmp"
+ git = "https://github.com/OpenMPToolsInterface/LLVM-openmp.git"
- # towards_tr4 branch
- version('towards_tr4', branch='towards_tr4',
- git='https://github.com/OpenMPToolsInterface/LLVM-openmp.git')
-
- version('3.9.2b2',
- git='https://github.com/OpenMPToolsInterface/LLVM-openmp.git',
- commit='5cdca5dd3c0c336d42a335ca7cff622e270c9d47')
+ # tr6_forwards branch
+ version('tr6_forwards', branch='tr6_forwards')
+ version('3.9.2b2', commit='5cdca5dd3c0c336d42a335ca7cff622e270c9d47')
# align-to-tr-rebased branch
- version('3.9.2b',
- git='https://github.com/OpenMPToolsInterface/LLVM-openmp.git',
- commit='982a08bcf3df9fb5afc04ac3bada47f19cc4e3d3')
+ version('3.9.2b', commit='982a08bcf3df9fb5afc04ac3bada47f19cc4e3d3')
# variant for building llvm-openmp-ompt as a stand alone library
variant('standalone', default=False,
@@ -79,9 +55,9 @@ class LlvmOpenmpOmpt(CMakePackage):
'-DCMAKE_BUILD_WITH_INSTALL_RPATH=true',
'-DLIBOMP_USE_DEBUGGER=false'])
# Build llvm-openmp-ompt using the toward_tr4 branch
# This requires the version to be 5.0 (50)
- if '@towards_tr4' in self.spec:
+ if '@tr6_forwards' in self.spec:
cmake_args.extend(
['-DLIBOMP_OMP_VERSION=50'])
@@ -79,9 +55,9 @@ class LlvmOpenmpOmpt(CMakePackage):
'-DCMAKE_BUILD_WITH_INSTALL_RPATH=true',
'-DLIBOMP_USE_DEBUGGER=false'])
- # Build llvm-openmp-ompt using the toward_tr4 branch
+ # Build llvm-openmp-ompt using the tr6_forwards branch
# This requires the version to be 5.0 (50)